@@ -67,6 +67,7 @@ pub mod prelude {
     pub use super::build::RenderablePlotIteratorExt;
     pub use super::formatm;
     pub use super::plotnum::TickFormatExt;
+    pub use super::plots;
     pub use super::simple_theme::SimpleTheme;
 }
 
@@ -93,6 +94,22 @@ macro_rules! formatm {
     }
 }
 
+///
+/// Macro to chain multiple plots together instead of caling [`chain`](build::RenderablePlotIteratorExt::chain) repeatedly.
+///
+#[macro_export]
+macro_rules! plots {
+    ( $a:expr,$( $x:expr ),* ) => {
+        {
+            let mut a=$a;
+            $(
+                let a=a.chain($x);
+            )*
+            a
+        }
+    };
+}
+
 ///
 /// Leverage rust's display format system using [`std::cell::RefCell`] under the hood.
 ///
